circkit: Circuit toolkit mainly for cryptographic usage
=======================================================

Description
-----------

Circuit toolkit mainly for cryptographic usage

License
-------

MIT

Upstream Contact
----------------

- https://pypi.org/project/circkit/
- https://github.com/passagemath/passagemath-pkg-circkit
